@@ -1,5 +1,5 @@
 from django.shortcuts import get_object_or_404, render
-from django.http import HttpResponseRedirect
+from django.http import HttpResponseRedirect, HttpResponse
 from django.core.urlresolvers import reverse
 from django.views.generic import ListView, DetailView, FormView
 from django.forms.formsets import formset_factory
@@ -127,7 +127,11 @@ class PollVoteView(FormView):
                 'Select a choice!')
                 
             messages.add_message(request, messages.WARNING, message)
-            return HttpResponseRedirect(request.path)
+            
+            if request.is_ajax():
+                return HttpResponse()
+            else:
+                return HttpResponseRedirect(request.path)
 
     def get_context_data(self, *args, **kwargs):
         context = super(PollVoteView, self).get_context_data(*args, **kwargs)
